# pade

Files for the Goedecker, Teter, Hutter (GTH) pseudopotential calculation. Phys. Rev. B 54, 1703.

To be used with a L(S)DA exchange-correlation functional.

Files taken from: https://github.com/cp2k/cp2k-data

The files can be updated with (only for maintaining purposes)

```terminal
python __init__.py
```
